@@ -37,7 +37,7 @@ from calculate.lib.utils import ip
 from calculate.lib.utils.portage import isPkgInstalled
 from operator import itemgetter
 from itertools import *
-from calculate.install.distr import DistributiveError
+from ..distr import DistributiveError
 
 
 class NetHelper(VariableInterface):
@@ -188,8 +188,7 @@ class VariableOsNetInterfacesInfo(NetHelper, ReadonlyVariable):
             else:
                 listInterfacesInfo.append((interface,
                                            ipaddr if ipaddr else _("Off")))
-        return ", ".join(map(lambda x: "%s (%s)" % (x[0], x[1]),
-                             listInterfacesInfo))
+        return ", ".join(("%s (%s)" % (x[0], x[1]) for x in listInterfacesInfo))
 
 
 class VariableOsInstallNetData(NetHelper, TableVariable):
@@ -310,11 +309,9 @@ class VariableOsInstallNetName(NetHelper, ReadonlyVariable):
                 return ""
 
         pciEthernet = lspci(shortInfo=True)
-        return map(lambda x: "{vendor} {name}".format(**x),
-                   map(lambda x: pciEthernet.get(getPci(x),
-                                                 {'vendor': _("Unknown"),
-                                                  'name': _("vendor")}),
-                       self.Get('os_install_net_interfaces')))
+        return ["{vendor} {name}".format(**x) for x 
+            in [pciEthernet.get(getPci(y), {'vendor': _("Unknown"), 'name': _("vendor")}) for y 
+                in self.Get('os_install_net_interfaces')]]
 
 
 class VariableOsInstallNetMacType(NetHelper, ReadonlyVariable):
@@ -336,7 +333,7 @@ class VariableOsInstallNetMacType(NetHelper, ReadonlyVariable):
             return "local"
 
     def get(self):
-        return map(self._mactype, self.Get('os_install_net_mac'))
+        return [self._mactype(x) for x in self.Get('os_install_net_mac')]
 
 
 class VariableOsInstallNetMac(NetHelper, ReadonlyVariable):
@@ -349,8 +346,7 @@ class VariableOsInstallNetMac(NetHelper, ReadonlyVariable):
         self.label = _("MAC")
 
     def get(self):
-        return map(lambda x: getMac(x).lower(),
-                   self.Get('os_install_net_interfaces'))
+        return [getMac(x).lower() for x in self.Get('os_install_net_interfaces')]
 
 
 class VariableOsInstallNetStatus(NetHelper, Variable):
@@ -363,8 +359,7 @@ class VariableOsInstallNetStatus(NetHelper, Variable):
         self.label = _("IP address")
 
     def get(self):
-        return map(self.getDefaultValue,
-                   self.Get('os_install_net_interfaces'))
+        return [self.getDefaultValue(x) for x in self.Get('os_install_net_interfaces')]
 
     def getDefaultValue(self, iface):
         def statusValue(ipaddr, dhcp):
@@ -387,16 +382,14 @@ class VariableOsInstallNetStatus(NetHelper, Variable):
             if rootDevNfs or isDhcpIp(iface) else "off")
 
     def set(self, value):
-        value = map(lambda x: x.lower() if x else x, value)
+        value = (x.lower() if x else x for x in value)
         ifaces = self.Get('os_install_net_interfaces')
-        return map(lambda x: self.getDefaultValue(x[1]) \
-            if x[0] == "auto" else x[0],
-                   zip(value, ifaces))
+        return [self.getDefaultValue(x[1]) if x[0] == "auto" else x[0] for x 
+            in zip(value, ifaces)]
 
     def check(self, value):
         for status in value:
-            if status not in map(lambda x: x[0], self.choice()) and \
-                    not checkIp(status):
+            if status not in (x[0] for x in self.choice()) and not checkIp(status):
                 raise VariableError(_("Wrong IP address %s") % status)
 
     def choice(self):
@@ -415,10 +408,10 @@ class VariableOsInstallNetIp(NetHelper, ReadonlyVariable):
         self.label = _("IP address")
 
     def get(self):
-        return map(lambda x: "" if x[1].lower() == "off" else
-        getIp(x[0]) if x[1].lower() == "dhcp" else x[1],
-                   zip(self.Get('os_install_net_interfaces'),
-                       self.Get('os_install_net_status')))
+        return ["" if x[1].lower() == "off" else
+            getIp(x[0]) if x[1].lower() == "dhcp" else x[1] for x 
+            in zip(self.Get('os_install_net_interfaces'),
+                self.Get('os_install_net_status'))]
 
         # def check(self,value):
         #    dhcps = self.Get('os_install_net_dhcp_set')
@@ -439,9 +432,9 @@ class VariableOsInstallNetNetwork(NetHelper, ReadonlyVariable):
         self.label = _("Network")
 
     def get(self):
-        return map(lambda x: getIpNet(x[0], x[1]) if x[0] and x[1] else "",
-                   zip(self.Get('os_install_net_ip'),
-                       self.Get('os_install_net_mask')))
+        return [getIpNet(x[0], x[1]) if x[0] and x[1] else "" for x 
+            in zip(self.Get('os_install_net_ip'),
+                self.Get('os_install_net_mask'))]
 
 
 class VariableOsInstallNetCidr(NetHelper, ReadonlyVariable):
@@ -457,8 +450,7 @@ class VariableOsInstallNetCidr(NetHelper, ReadonlyVariable):
         """
         Get CIDR of ip,net (Example: 24)
         """
-        return map(lambda x: maskToCidr(x) if x else '',
-                   self.Get('os_install_net_mask'))
+        return [maskToCidr(x) if x else '' for x in self.Get('os_install_net_mask')]
 
 
 class VariableOsInstallNetMask(NetHelper, Variable):
@@ -471,8 +463,8 @@ class VariableOsInstallNetMask(NetHelper, Variable):
         self.label = _("Mask")
 
     def get(self):
-        return map(lambda x: cidrToMask(getMask(x)),
-                   self.Get('os_install_net_interfaces'))
+        return [cidrToMask(getMask(x)) for x 
+            in self.Get('os_install_net_interfaces')]
 
     def set(self, value):
         """
@@ -485,14 +477,13 @@ class VariableOsInstallNetMask(NetHelper, Variable):
             else:
                 return x
 
-        res = map(convertCidrToMask, value)
+        res = [convertCidrToMask(x) for x in value]
         return res
 
     def check(self, value):
         dhcps = self.Get('os_install_net_status')
-        wrongMask = filter(lambda x: (x[0] or not x[1] in ("off", "dhcp")) and \
-                                     not checkMask(x[0]),
-                           zip(value, dhcps))
+        wrongMask = [x for x in zip(value, dhcps) 
+            if (x[0] or not x[1] in ("off", "dhcp")) and not checkMask(x[0])]
         if wrongMask:
             raise VariableError(_("Wrong mask %s") % wrongMask[0][0])
 
@@ -514,8 +505,8 @@ class VariableOsInstallNetDhcpSet(NetHelper, Variable):
         self.label = _("DHCP")
 
     def get(self):
-        return map(lambda x: "on" if x == "dhcp" else "off",
-                   self.Get('os_install_net_status'))
+        return ["on" if x == "dhcp" else "off" for x 
+            in self.Get('os_install_net_status')]
 
 
 class VariableOsInstallNetRouteData(NetHelper, TableVariable):
@@ -544,19 +535,18 @@ class VariableOsInstallNetRouteData(NetHelper, TableVariable):
         interfaces = self.Get('os_install_net_interfaces')
         interfaces_status = self.Get('os_install_net_status')
         interfaces_network = self.Get('os_install_net_network')
-        staticInterface = \
-            map(itemgetter(0, 2),
-                filter(lambda x: not x[1] in ("off", "dhcp"),
-                       zip(interfaces, interfaces_status, interfaces_network)))
+        staticInterface = [itemgetter(0, 2)(x) for x 
+            in zip(interfaces, interfaces_status, interfaces_network) 
+            if not x[1] in ("off", "dhcp")]
         route_data = []
         if staticInterface:
             staticInterface, skipNet = zip(*staticInterface)
-            return map(lambda x: [x[0],
-                                  x[1].get('via', ''),
-                                  x[1].get('dev', ''),
-                                  x[1].get('src', '')],
-                       ifilter(lambda x: not x[0] in skipNet,
-                               ip.getRouteTable(staticInterface))) or [[]]
+            return [[x[0],
+                    x[1].get('via', ''),
+                    x[1].get('dev', ''),
+                    x[1].get('src', '')] for x 
+                    in ip.getRouteTable(staticInterface)
+                    if not x[0] in skipNet] or [[]]
         return [[]]
 
     def getHumanReadableAuto(self):
@@ -598,12 +588,11 @@ class VariableOsInstallNetRouteNetwork(NetHelper, FieldValue, Variable):
         ##########################
         # detect duplicate network
         ##########################
-        for wrongnet in ifilterfalse(ip.checkNet,
-                                     ifilter("default".__ne__,
+        for wrongnet in filterfalse(ip.checkNet,
+                                     filter("default".__ne__,
                                              value)):
             raise VariableError(_("Wrong network %s") % wrongnet)
-        dupNetwork = list(set(filter(lambda x: value.count(x) > 1,
-                                     value)))
+        dupNetwork = list(set([x for x in value if value.count(x) > 1]))
         if dupNetwork:
             raise VariableError(
                 _("Network '%s' is used more than once") % dupNetwork[0])
@@ -626,19 +615,14 @@ class VariableOsInstallNetRouteGw(NetHelper, FieldValue, Variable):
         NET, GW = 0, 1
         netsGw = zip(self.Get('os_install_net_route_network'),
                      value)
-        nets = filter(lambda x: x and x != "default",
-                      chain(self.Get('os_install_net_route_network'),
-                            self.Get('os_install_net_network')))
+        nets = [x for x in chain(self.Get('os_install_net_route_network'),
+                                self.Get('os_install_net_network'))
+                if x and x != "default"]
 
-        for wrongip in ifilterfalse(ip.checkIp, value):
+        for wrongip in filterfalse(ip.checkIp, value):
             raise VariableError(_("Wrong gateway IP %s") % wrongip)
-
-        wrongGws = map(lambda x: x[GW],
-                       filter(lambda x: not ip.isIpInNet(x[GW],
-                                                         *(set(nets) - set(
-                                                             x[NET]))),
-                              filter(lambda x: x[GW],
-                                     netsGw)))
+        wrongGws = [x[GW] for x in [y for y in netsGw if y[GW]] 
+            if not ip.isIpInNet(x[GW], *(set(nets) - set(x[NET])))]
         if wrongGws:
             raise VariableError(_("Gateways %s are unreachable") %
                                 (",".join(wrongGws)))
@@ -674,12 +658,11 @@ class VariableOsInstallNetRouteSrc(NetHelper, FieldValue, Variable):
         return [""] + self.Get('os_install_net_ip')
 
     def check(self, value):
-        for wrongip in ifilterfalse(ip.checkIp,
-                                    ifilter(None, value)):
+        for wrongip in filterfalse(ip.checkIp,
+                                    filter(None, value)):
             raise VariableError(_("Wrong source IP %s") % wrongip)
         ipAddrs = self.Get('os_install_net_ip')
-        wrongIps = filter(lambda x: x and not x in ipAddrs,
-                          value)
+        wrongIps = [x for x in value if x and not x in ipAddrs]
         if wrongIps:
             raise VariableError(
                 _("Wrong IP address %s in the specified source IP") %
@@ -697,14 +680,13 @@ class VariableOsInstallNetRoute(NetHelper, ReadonlyVariable):
                           self.Get('os_install_net_route_dev'),
                           self.Get('os_install_net_route_src'))
         DEV, IP, CIDR, NET = 0, 1, 2, 1
-        return map(lambda x: performFunc(x[DEV], x[NET], routeMatrix),
-                   # union ip and mask to ip/net
-                   map(lambda x: (x[DEV], ip.getIpNet(x[IP], cidr=x[CIDR])) \
-                       if x[IP] and x[CIDR] else (x[DEV], ""),
-                       # filter(lambda x:x[IP] and x[CIDR],
-                       zip(self.Get('os_install_net_interfaces'),
+        return [performFunc(x[DEV], x[NET], routeMatrix) for x 
+            # ip and mask to ip/net
+            in [(y[DEV], ip.getIpNet(y[IP], cidr=y[CIDR])) 
+                if y[IP] and y[CIDR] else (y[DEV], "") for y
+                in zip(self.Get('os_install_net_interfaces'),
                            self.Get('os_install_net_ip'),
-                           self.Get('os_install_net_cidr'))))
+                           self.Get('os_install_net_cidr'))]]
 
     def get(self):
         """Route info for conf.d/net"""
@@ -719,10 +701,11 @@ class VariableOsInstallNetRoute(NetHelper, ReadonlyVariable):
             NET, GW, DEV, SRC = 0, 1, 2, 3
             # filter by interface and discard direct routes
             # example: for 192.168.1.5/24 discard 192.168.1.0/24 net
-            route_list = filter(lambda x: (interface == x[DEV] or defaultDev and
-                                      interface == defaultDev) \
-                                     and net != x[NET], routeMatrix)
-
+            route_list = [x for x in routeMatrix 
+                if (interface == x[DEV] or 
+                defaultDev and 
+                interface == defaultDev) and
+                net != x[NET]]
             nets = []
             route_list_uniqnet = []
             for net, gw, dev, src in route_list:
@@ -730,10 +713,9 @@ class VariableOsInstallNetRoute(NetHelper, ReadonlyVariable):
                     route_list_uniqnet.append([net, gw, dev, src])
                     nets.append(net)
 
-            route_strs = map(lambda x: "{net}{gateway}{src}".format(
-                    net=x[NET],
-                    gateway=" via %s" % x[GW] if x[GW] else "",
-                    src=" src %s" % x[SRC] if x[SRC] else ""), route_list_uniqnet)
+            route_strs = ("{net}{gateway}{src}".format(net=x[NET], gateway=" via %s" % x[GW] 
+                    if x[GW] else "", src=" src %s" % x[SRC] if x[SRC] else "") for x 
+                in route_list_uniqnet)
             # build string for route from net,gateway,dev and src
             return "\n".join(route_strs)
 
@@ -757,29 +739,42 @@ class VariableOsInstallNetNmroute(VariableOsInstallNetRoute):
 
         def getRouteForInterfaceNM(interface, net, routeMatrix):
             NET, GW, DEV, SRC = 0, 1, 2, 3
-            defaultGw = map(lambda x: "%s;" % x[GW],
-                            filter(lambda x: interface == x[DEV] and \
-                                             x[NET] == "default",
-                                   routeMatrix))
-            return "{0}\n".format(defaultGw[0] if defaultGw else "") + \
-                   "\n".join(
-                       # build string for route from net,gateway,dev and src
-                       map(lambda
-                               x: "routes{num}={ip};{cidr};{gateway};0;".format(
+            defaultGw = ["%s;" % x[GW] for x in routeMatrix 
+                if interface == x[DEV] and x[NET] == "default"]
+            # return "{0}\n".format(defaultGw[0] if defaultGw else "") + \
+            #        "\n".join(
+            #            # build string for route from net,gateway,dev and src
+            #            map(lambda
+            #                    x: "routes{num}={ip};{cidr};{gateway};0;".format(
+            #                num=x[0] + 1,
+            #                ip=x[1][NET].partition('/')[0],
+            #                cidr=x[1][NET].partition('/')[2],
+            #                gateway=x[1][GW] if x[1][GW] else "0.0.0.0"),
+            #                # filter by interface and discard direct routes
+            #                # example: for 192.168.1.5/24 discard 192.168.1.0/24 net
+            #                enumerate(
+            #                    filter(lambda x: (interface == x[
+            #                        DEV] or defaultDev and
+            #                                      interface == defaultDev) and net !=
+            #                                                                   x[
+            #                                                                       NET] and \
+            #                                     x[NET] != "default",
+            #                           routeMatrix))))
+            return "{0}\n".format(defaultGw[0] if defaultGw else "") + "\n".join(
+                # build string for route from net,gateway,dev and src
+                ("routes{num}={ip};{cidr};{gateway};0;".format(
                            num=x[0] + 1,
                            ip=x[1][NET].partition('/')[0],
                            cidr=x[1][NET].partition('/')[2],
-                           gateway=x[1][GW] if x[1][GW] else "0.0.0.0"),
-                           # filter by interface and discard direct routes
-                           # example: for 192.168.1.5/24 discard 192.168.1.0/24 net
-                           enumerate(
-                               filter(lambda x: (interface == x[
-                                   DEV] or defaultDev and
-                                                 interface == defaultDev) and net !=
-                                                                              x[
-                                                                                  NET] and \
-                                                x[NET] != "default",
-                                      routeMatrix))))
+                           gateway=x[1][GW] if x[1][GW] else "0.0.0.0") for x 
+                # filter by interface and discard direct routes
+                # example: for 192.168.1.5/24 discard 192.168.1.0/24 net
+                in enumerate((x for x in routeMatrix 
+                    if (interface == x[DEV] or 
+                    defaultDev and 
+                    interface == defaultDev) and 
+                    net !=x[NET] and 
+                    x[NET] != "default"))))
 
         return self.performRouteData(getRouteForInterfaceNM)
 
@@ -799,10 +794,8 @@ class VariableOsInstallNetConfAvailable(NetHelper, Variable):
             with image as distr:
                 try:
                     distrPath = image.getDirectory()
-                    return map(itemgetter(0, 2),
-                               filter(lambda x: not x[1] or isPkgInstalled(x[1],
-                                                                           prefix=distrPath),
-                                      mapNetConf))
+                    return [itemgetter(0, 2)(x) for x in mapNetConf 
+                        if not x[1] or isPkgInstalled(x[1], prefix=distrPath)]
                 except DistributiveError as e:
                     pass
         return sorted(map(itemgetter(0, 2), mapNetConf[-1:]), key=itemgetter(1))
@@ -822,10 +815,9 @@ class VariableOsInstallNetConf(NetHelper, Variable):
 
     def get(self):
         """Net setup (networkmanager or openrc)"""
-        if filter(lambda x: x.lower() == "networkmanager",
-                  listDirectory('/etc/runlevels/boot') +
-                          listDirectory('/etc/runlevels/default')) \
-                or self.Get('os_root_type') == "livecd":
+        if [x for x in listDirectory('/etc/runlevels/boot') + 
+            listDirectory('/etc/runlevels/default')
+            if x.lower() == "networkmanager"] or self.Get('os_root_type') == "livecd":
             nm = "networkmanager"
         else:
             nm = ""
@@ -867,10 +859,9 @@ class VariableOsInstallNetDnsSearch(NetHelper, Variable):
 
     def get(self):
         """Get current name servers"""
-        dnsSearch = " ".join(
-            map(lambda x: x.strip().partition("search")[2].strip(),
-                filter(lambda x: x.lstrip().startswith("search"),
-                       readLinesFile('/etc/resolv.conf'))))
+        dnsSearch = " ".join((x.strip().partition("search")[2].strip() for x 
+            in readLinesFile('/etc/resolv.conf') 
+            if x.lstrip().startswith("search")))
         return "" if self.isDNSByDHCP() else dnsSearch
 
     def humanReadable(self):
@@ -894,17 +885,16 @@ class VariableOsInstallNetDns(VariableOsInstallNetDnsSearch):
         return " ".join(re.split('[; ,]', value))
 
     def get(self):
-        dnsIps = filter(ip.checkIp,
-                        map(lambda x: x.strip().partition("nameserver")[
-                            2].strip(),
-                            filter(
-                                lambda x: x.lstrip().startswith("nameserver"),
-                                readLinesFile('/etc/resolv.conf'))))
+        dnsIps = (x for x 
+            in (y.strip().partition("nameserver")[2].strip() for y 
+                in readLinesFile('/etc/resolv.conf') 
+                if y.lstrip().startswith("nameserver")) 
+            if ip.checkIp(x))
         return "" if self.isDNSByDHCP() else " ".join(dnsIps)
 
     def check(self, value):
         reIp = re.compile(ip.IP_ADDR)
-        if any(ifilterfalse(reIp.match, value.split(' '))):
+        if any(filterfalse(reIp.match, value.split(' '))):
             raise VariableError(_("Wrong IP address for DNS"))
 
     def humanReadable(self):
@@ -938,11 +928,11 @@ class VariableOsInstallPxeIp(Variable):
 
     def get(self):
         ips = self.Get('os_net_ip').split(',')
-        for ipaddr in ifilter(None, ips):
+        for ipaddr in filter(None, ips):
             return ipaddr
         else:
             return ""
 
     def choice(self):
         ips = self.Get('os_net_ip').split(',')
-        return filter(None, ips)
+        return [x for x in ips if x]
